@@ -19,6 +19,7 @@
 #' )}
 #' @param visConfig An optional config string to reproduce your chart. You can copy the string by clicking "export config" button on the GWalkR interface.
 #' @param visConfigFile An optional config file path to reproduce your chart. You can download the file by clicking "export config" button then "download" button on the GWalkR interface.
+#' @param toolbarExclude An optional list of strings to exclude the tools from toolbar UI. However, Kanaries brand info is not allowed to be removed or changed unless you are granted with special permission.
 #'
 #' @return An \code{htmlwidget} object that can be rendered in R environments
 #'
@@ -27,7 +28,7 @@
 #' gwalkr(mtcars)
 #'
 #' @export
-gwalkr <- function(data, lang = "en", dark = "light", columnSpecs = list(), visConfig = NULL, visConfigFile = NULL) {
+gwalkr <- function(data, lang = "en", dark = "light", columnSpecs = list(), visConfig = NULL, visConfigFile = NULL, toolbarExclude = list()) {
   if (!is.data.frame(data)) stop("data must be a data frame")
   if (!is.null(visConfig) && !is.null(visConfigFile)) stop("visConfig and visConfigFile are mutually exclusive")
   lang <- match.arg(lang, choices = c("en", "ja", "zh"))
@@ -43,9 +44,9 @@ gwalkr <- function(data, lang = "en", dark = "light", columnSpecs = list(), visC
     dataSource = jsonlite::toJSON(data),
     rawFields = rawFields,
     i18nLang = lang,
-    hideDataSourceConfig = TRUE,
     visSpec = visConfig,
-    dark = dark
+    dark = dark,
+    toolbarExclude = toolbarExclude
   )
 
   # create widget
